/*
 * Author: Jake G
 * Date: 2024
 * filename: LedController.c
 * description: Abstract LED interface and control.
 */

#ifndef __AVR_ATtiny404__
#define __AVR_ATtiny404__
#endif

#include "LedController.h"
#include "avr/io.h"

#define LED_BM_PORTA (1 << 6) | (1 << 1) | (1 << 2) | (1 << 3)
#define LED_BM_PORTB (1 << 3) | (1 << 2) | (1 << 0) | (1 << 1)

LedByte LedController_New(uint8_t *port) {
  LedByte led_byte;
  for (int i = 0; i < 8; i++) {
    led_byte.leds[i].pin_num = i;
    led_byte.leds[i].state = false;
    led_byte.leds[i].port = port;
  }
  return led_byte;
}

void LedController_ShowByte(LedByte *led_byte, uint8_t byte) {
  for (int i = 0; i < 8; i++) {
    if (byte & (1 << i)) {
      LedController_SetHigh(&led_byte->leds[i]);
    } else {
      LedController_SetLow(&led_byte->leds[i]);
    }
  }
}

void LedControler_ClearByte(LedByte *led_byte) {
  for (int i = 0; i < 8; i++) {
    LedController_SetLow(&led_byte->leds[i]);
  }
}

void LedController_SetHigh(Led *led) {
  *led->port |= (1 << led->pin_num);
  led->state = true;
  return;
}

void LedController_SetLow(Led *led) {
  *led->port &= ~(1 << led->pin_num);
  led->state = false;
  return;
}
